pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Jean-Pierre Pelletier <pelletier_32@sympatico.ca>
To: josh@agliodbs.com
To: pgsql-performance@postgresql.org
Cc: John Arbash Meinel <john@arbash-meinel.com>
Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0
Date: Thu, 22 Sep 2005 21:41:37 -0400
Message-ID: <BAYC1-PASMTP044401579071F97B30C53F95960@CEZ.ICE> (raw)
References: <BAYC1-PASMTP01EE67AD3A0034394D85D895970@CEZ.ICE>
	<433326A6.8010708@arbash-meinel.com>
	<BAYC1-PASMTP0276B50280C40ABC9BBCB495970@CEZ.ICE>
	<200509221519.05555.josh@agliodbs.com>

Explain analyze on my 8.0.1 installation does report the time for
slower queries but for this small query it reports 0.000 ms

----- Original Message ----- 
From: "Josh Berkus" <josh@agliodbs.com>
To: <pgsql-performance@postgresql.org>
Cc: "Jean-Pierre Pelletier" <pelletier_32@sympatico.ca>; "John Arbash 
Meinel" <john@arbash-meinel.com>
Sent: Thursday, September 22, 2005 6:19 PM
Subject: Re: [PERFORM] Queries 15 times slower on 8.1 beta 2 than on 8.0


> Jean-Pierre,
>
> First off, you're on Windows?
>
>> "  ->  Seq Scan on price p  (cost=0.00..11317.75 rows=581475 width=4)
>> (actual time=0.004..1143.720 rows=581475 loops=1)"
>
> Well, this is your pain point.   Can we see the index scan plan on 8.1?
> Given that it's *expecting* only one row, I can't understand why it's
> using a seq scan ...
>
>> "Nested Loop Left Join  (cost=0.00..11.02 rows=1 width=0) (actual
>> time=0.000..0.000 rows=1 loops=1)"
>> "  ->  Nested Loop Left Join  (cost=0.00..5.48 rows=1 width=4) (actual
>> time=0.000..0.000 rows=1 loops=1)"
>> "Total runtime: 0.000 ms"
>
> Feh, this looks like the "windows does not report times" bug, which makes
> it hard to compare ...
>
> -- 
> --Josh
>
> Josh Berkus
> Aglio Database Solutions
> San Francisco
>
> ---------------------------(end of broadcast)---------------------------
> TIP 3: Have you checked our extensive FAQ?
>
>               http://www.postgresql.org/docs/faq 




view thread (21+ messages)

Message-ID: <BAYC1-PASMTP044401579071F97B30C53F95960@CEZ.ICE>
Permalink:  ../BAYC1-PASMTP044401579071F97B30C53F95960@CEZ.ICE/
Also on:    postgresql.org/message-id/BAYC1-PASMTP044401579071F97B30C53F95960@CEZ.ICE

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: pelletier_32@sympatico.ca, josh@agliodbs.com, john@arbash-meinel.com
  Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0
  In-Reply-To: <BAYC1-PASMTP044401579071F97B30C53F95960@CEZ.ICE>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox